Optimization of clone positions and proportion of mutations in each clone.
EM.algo(Schrod, nclust = NULL, prior_center = NULL, prior_weight = NULL,
contamination, epsilon = 10^(-2), optim = "default")A list of dataframes (one for each sample), generated by the Patient_schrodinger_cellularities() function.
Number of clones to look for (mandatory if prior_center or prior_weight are null)
Clone coordinates (from another analysis) to be used
Prior on the fraction of mutation in each clone
Numeric vector with the fraction of normal cells contaminating the sample
Stop value: maximal admitted value of the difference in cluster position and weights between two optimization steps. If NULL, will take 1/(median depth).
use L-BFS-G optimization from R ("default"), or from optimx ("optimx")