Maximization of the likelihood given a mixture of binomial distributions
EM_clustering(Schrod, contamination, prior_weight = NULL,
clone_priors = NULL, Initializations = 1, nclone_range = 2:5,
epsilon = 0.01, ncores = 2, model.selection = "BIC",
optim = "default", keep.all.models = FALSE, FLASH = FALSE)List of dataframes, output of the Schrodinger function or the EM algorithm
The fraction of normal cells in the sample
If known a list of priors (fraction of mutations in a clone) to be used in the clustering
If known a list of priors (cell prevalence) to be used in the clustering
Maximal number of independant initial condition tests to be tried
Number of clusters to look for
Stop value: maximal admitted value of the difference in cluster position and weights between two optimization steps.
Number of CPUs to be used
The function to minimize for the model selection: can be "AIC", "BIC", or numeric. In numeric, the function uses a variant of the BIC by multiplication of the k*ln(n) factor. If >1, it will select models with lower complexity.
use L-BFS-G optimization from R ("default"), or from optimx ("optimx"), or Differential Evolution ("DEoptim")
Should the function output the best model (default; FALSE), or all models tested (if set to true)
should it use FLASH algorithm to create priors