Learn R Programming

QuantumClone (version 1.0.0.6)

multiplot_trees: Plots multiple trees

Description

Plots all trees created by the function Tree_generation. The red line means that mutations occured.

Usage

multiplot_trees(result_list, d, cex = 0.8)

Arguments

result_list

List of lists (tree generated and the probability associated with each tree)

d

Number of clusters found by QuantumClone

cex

Coefficient of expansion for the texts in phylogenetic tree plots. Default is 0.8

Examples

Run this code
# NOT RUN {
multiplot_trees(QuantumClone::Tree, d= 4)
# }

Run the code above in your browser using DataLab