Learn R Programming

QuantumClone (version 1.0.0.6)

zscore: Z-score

Description

Computes the z-score of mutations being from the same distribution

Usage

zscore(Depth, Alt)

Arguments

Depth

a numeric vector of depth of sequencing for each variant

Alt

a numeric vector of the number of reads supporting each variant

Value

returns a square numeric matrix