filter_on_fik: Data filter
Description
Keep one possibility per position and ajust weight accordingly
Usage
filter_on_fik(Schrod, fik)
Arguments
Schrod
A list of dataframes (one for each sample), generated by the Patient_schrodinger_cellularities.
fik
matrix of probability of each possibility to belong to a clone