find_x_position: Graphic position
Description
Computes the position of a node on the graph, based on the interaction matrix.
Usage
find_x_position(matrix, n, d)
Arguments
matrix
The interaction matrix of the tree (1 on the i-th row j-th column means "clone j is the progeny of clone i")
n
Index of the clone of interest in the matrix