powered by
Returns the product of all elements in a list, e.g. a vector if the elements of the list are vectors, etc.
list_prod(L, col = NULL)
list used
If it is a list of matrices, and only one column should be used, name of the column.
# NOT RUN { list_prod(list(matrix(1:4,nrow = 2),matrix(1:4,nrow = 2))) # }
Run the code above in your browser using DataLab