powered by
Plots all trees created by the function Tree_generation. The red line means that mutations occured.
multiplot_trees(result_list, d, cex = 0.8)
List of lists (tree generated and the probability associated with each tree)
Number of clusters found by QuantumClone
Coefficient of expansion for the texts in phylogenetic tree plots. Default is 0.8
# NOT RUN { multiplot_trees(QuantumClone::Tree, d= 4) # }
Run the code above in your browser using DataLab