powered by
Computes the z-score of mutations being from the same distribution
zscore(Depth, Alt)
a numeric vector of depth of sequencing for each variant
a numeric vector of the number of reads supporting each variant
returns a square numeric matrix